@@ -1,12 +1,17 @@
-import pytest
-from conftest import needs_libqpdf_v
+# SPDX-FileCopyrightText: 2022 James R. Barlow
+# SPDX-License-Identifier: CC0-1.0
 
-from pikepdf import Annotation, Dictionary, Name, Pdf
+from __future__ import annotations
+
+import pytest
+
+from pikepdf import Annotation, Name, Pdf
 
 
 @pytest.fixture
 def form(resources):
-    yield Pdf.open(resources / 'form.pdf')
+    with Pdf.open(resources / 'form.pdf') as pdf:
+        yield pdf
 
 
 def test_button(form):
