@@ -3,8 +3,6 @@
 
 from __future__ import annotations
 
-import os
-from datetime import timedelta
 from io import BytesIO
 from pathlib import Path
 
@@ -95,30 +93,35 @@ pdfdoc_text = text(
 
 
 @given(pdfdoc_text)
-@settings(deadline=timedelta(seconds=4))  # CI workers can be flakey
+@example('\r\n')
+@example('\r')
+@example('\n')
+@settings(deadline=60000)  # CI workers can be flakey
 def test_open_encoding_pdfdoc_write(tmp_path_factory, s):
     folder = tmp_path_factory.mktemp('pdfdoc')
     txt = folder / 'pdfdoc.txt'
-    with open(txt, 'w', encoding='pdfdoc') as f:
+    with open(txt, 'w', encoding='pdfdoc', newline='') as f:
         try:
             f.write(s)
         except UnicodeEncodeError:
             return
-    assert txt.read_bytes().replace(b'\r\n', b'\n') == s.encode('pdfdoc')
+    assert txt.read_bytes() == s.encode('pdfdoc')
 
 
 @given(pdfdoc_text)
-@settings(deadline=timedelta(seconds=4))  # CI workers can be flakey
+@settings(deadline=60000)  # CI workers can be flakey
+@example('\r\n')
+@example('\r')
+@example('\n')
 def test_open_encoding_pdfdoc_read(tmp_path_factory, s: str):
-    s = s.replace('\r', '\n')
     folder = tmp_path_factory.mktemp('pdfdoc')
     txt: Path = folder / 'pdfdoc.txt'
-    try:
-        txt.write_text(s, encoding='pdfdoc')
-    except UnicodeEncodeError:
-        return
-
-    with open(txt, encoding='pdfdoc') as f:
+    with open(txt, 'w', encoding='pdfdoc', newline='') as f:
+        try:
+            f.write(s)
+        except UnicodeEncodeError:
+            return
+    with open(txt, encoding='pdfdoc', newline='') as f:
         result: str = f.read()
     assert result == s
 
@@ -145,3 +148,9 @@ def test_stream_reader(s):
     sr = pikepdf.codec.PdfDocStreamReader(bio)
     result = sr.read()
     assert result == s
+
+
+def test_pdfdoc_encode_lookup_error():
+    not_in_pdfdoc = '你好'
+    with pytest.raises(LookupError):
+        not_in_pdfdoc.encode('pdfdoc_pikepdf', errors="invalid error handler")
